# Release history

## Release 0.8.8 (2023)
Intermediatery release that includes bug fixes, code cleanup and new features to support endPoint FBA. Has alpha support for Flux Balance Constraints V3 features including quadratic objectives, non-storichiometric user constraints and KeyValue pairs. Try the latest format with cbmpy.writeSBML3FBCV3.

## Release 0.8.4 (2022)
Primarily a Python 3.x compatability release

## Release 0.8.2 (2021)
## Release 0.8.1 (2021-07-23)
Primarily a bugfix release to fix the SymPy compatability issues as well as improved requirements handling.





(c) Brett G. Olivier, Amsterdam, 2023
cbmpy.writeSBML3FBCV2(